==> starkbank-ecdsa-0.1.4.tar.gz: starkbank-ecdsa-0.1.4/ellipticcurve/utils/binary.py <==
from binascii import hexlify, unhexlify


class BinaryToAscii:

    @classmethod
    def hexFromBinary(cls, data):
        """
        Return the hexadecimal representation of the binary data. Every byte of data is converted into the
        corresponding 2-digit hex representation. The resulting string is therefore twice as long as the length of data.

        :param data: binary
        :return: hexadecimal string
        """
        return hexlify(data)

    @classmethod
    def binaryFromHex(cls, data):
        """
        Return the binary data represented by the hexadecimal string hexstr. This function is the inverse of b2a_hex().
        hexstr must contain an even number of hexadecimal digits (which can be upper or lower case), otherwise a TypeError is raised.

        :param data: hexadecimal string
        :return: binary
        """
        return unhexlify(data)

    @classmethod
    def numberFrom(cls, string):
        """
        Get a number representation of a string

        :param String to be converted in a number
        :return: Number in hex from string
        """
        return int(cls.hexFromBinary(string), 16)

    @classmethod
    def stringFrom(cls, number, length):
        """
        Get a string representation of a number

        :param number to be converted in a string
        :param length max number of character for the string
        :return: hexadecimal string
        """
        fmtStr = "%0" + str(2 * length) + "x"
        string = cls.binaryFromHex((fmtStr % number).encode())
        return string

==> starkbank-ecdsa-1.1.0.tar.gz: starkbank-ecdsa-1.1.0/ellipticcurve/utils/binary.py <==
from .compatibility import *


class BinaryAscii:

    @classmethod
    def hexFromBinary(cls, data):
        """
        Return the hexadecimal representation of the binary data. Every byte of data is converted into the
        corresponding 2-digit hex representation. The resulting string is therefore twice as long as the length of data.

        :param data: binary
        :return: hexadecimal string
        """
        return safeHexFromBinary(data)

    @classmethod
    def binaryFromHex(cls, data):
        """
        Return the binary data represented by the hexadecimal string hexstr. This function is the inverse of b2a_hex().
        hexstr must contain an even number of hexadecimal digits (which can be upper or lower case), otherwise a TypeError is raised.

        :param data: hexadecimal string
        :return: binary
        """
        return safeBinaryFromHex(data)

    @classmethod
    def numberFromString(cls, string):
        """
        Get a number representation of a string

        :param String to be converted in a number
        :return: Number in hex from string
        """
        return int(cls.hexFromBinary(string), 16)

    @classmethod
    def stringFromNumber(cls, number, length):
        """
        Get a string representation of a number

        :param number to be converted in a string
        :param length max number of character for the string
        :return: hexadecimal string
        """

        fmtStr = "%0" + str(2 * length) + "x"
        return toString(cls.binaryFromHex((fmtStr % number).encode()))
